@@ -1,6 +1,6 @@
 /*
  * Copyright 2021 Marius Gripsgard <marius@ubports.com>
- * Copyright 2021 Robert Tari <robert@tari.in>
+ * Copyright 2021-2023 Robert Tari <robert@tari.in>
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -16,13 +16,25 @@
  */
 
 #include "utils.h"
-
+#include <glib/gi18n-lib.h>
 #include <string.h>
 
 #ifdef LOMIRI_FEATURES_ENABLED
 # include <lomiri-url-dispatcher.h>
 #endif
 
+static gboolean bI18nInit = FALSE;
+
+static void initI18n ()
+{
+    if (!bI18nInit)
+    {
+        bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+        bI18nInit = TRUE;
+    }
+}
+
 // TODO: make case insensitive
 gboolean
 is_xdg_current_desktop (const gchar* desktop, const gchar* session)
@@ -304,3 +316,61 @@ void ayatana_common_utils_ellipsize(char *sText)
         memcpy(pLastChar, "...\0", 4);
     }
 }
+
+gboolean ayatana_common_utils_execute_command_warn (const gchar *sProgram, const gchar *sArgs)
+{
+    gboolean bHasProgram = ayatana_common_utils_have_program (sProgram);
+
+    if (!bHasProgram)
+    {
+        initI18n ();
+        gchar *sMessage = g_strdup_printf (_("The %s program is required for this action, but it was not found."), sProgram);
+        ayatana_common_utils_zenity_warning ("dialog-warning", _("Warning"), sMessage);
+        g_free (sMessage);
+
+        return FALSE;
+    }
+
+    gchar *sCommand = g_strdup_printf ("%s %s", sProgram, sArgs);
+    gboolean bSuccess = ayatana_common_utils_execute_command (sCommand);
+    g_free (sCommand);
+
+    return bSuccess;
+}
+
+gboolean ayatana_common_utils_zenity_question (const gchar *sIcon, const gchar *sTitle, const gchar *sText, const gchar *sOk, const gchar *sCancel)
+{
+    gchar *sZenity = g_find_program_in_path ("zenity");
+    gchar *sCommand = g_strdup_printf ("%s --question --icon-name=\"%s\" --title=\"%s\" --text=\"%s\" --ok-label=\"%s\" --cancel-label=\"%s\" --no-wrap", sZenity, sIcon, sTitle, sText, sOk, sCancel);
+    g_free (sZenity);
+    int nStatus = -1;
+    GError *pError = NULL;
+    gboolean bConfirmed = FALSE;
+
+    if (!g_spawn_command_line_sync (sCommand, NULL, NULL, &nStatus, &pError))
+    {
+        bConfirmed = TRUE;
+    }
+    else
+    {
+        #if GLIB_CHECK_VERSION(2, 70, 0)
+            bConfirmed = g_spawn_check_wait_status (nStatus, &pError);
+        #else
+            bConfirmed = g_spawn_check_exit_status (nStatus, &pError);
+        #endif
+    }
+
+    if (pError)
+    {
+        if (!g_error_matches (pError, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        {
+            g_warning ("%s %s: %s", G_STRLOC, G_STRFUNC, pError->message);
+        }
+
+        g_clear_error (&pError);
+    }
+
+    g_free (sCommand);
+
+    return bConfirmed;
+}
